@@ -16,34 +16,36 @@ factory <- function(tab,
                     add_rows = NULL,
                     add_columns = NULL,
                     escape = TRUE,
+                    output_factory = "tinytable",
+                    output_format = "tinytable",
+                    output_file = NULL,
                     ...) {
 
 
   # sanity check functions are hosted in R/sanity_checks.R
   sanity_title(title, ...)
   sanity_notes(notes)
-  # sanitize_output(output) # do not override (otherwise this breaks quarto for shape="rbind")
 
   # parse output
   if (isTRUE(output == "data.frame")) { # internal calls from datasummary_skim()
     factory_fun <- factory_dataframe
-  } else if (settings_equal("output_factory", "gt")) {
+  } else if (output_factory == "gt") {
     factory_fun <- factory_gt
-  } else if (settings_equal("output_factory", "tinytable")) {
+  } else if (output_factory == "tinytable") {
     factory_fun <- factory_tinytable
-  } else if (settings_equal("output_factory", "kableExtra")) {
+  } else if (output_factory == "kableExtra") {
     factory_fun <- factory_kableExtra
-  } else if (settings_equal("output_factory", "flextable")) {
+  } else if (output_factory == "flextable") {
     factory_fun <- factory_flextable
-  } else if (settings_equal("output_factory", "huxtable")) {
+  } else if (output_factory == "huxtable") {
     factory_fun <- factory_huxtable
-  } else if (settings_equal("output_factory", "DT")) {
+  } else if (output_factory == "DT") {
     factory_fun <- factory_DT
-  } else if (settings_equal("output_factory", "dataframe")) {
+  } else if (output_factory == "dataframe") {
     factory_fun <- factory_dataframe
-  } else if (settings_equal("output_factory", "modelsummary")) {
+  } else if (output_factory == "modelsummary") {
     factory_fun <- factory_markdown
-  } else if (settings_equal("output_factory", "typst")) {
+  } else if (output_factory == "typst") {
     factory_fun <- factory_typst
   }
 
@@ -52,8 +54,8 @@ factory <- function(tab,
   if (!is.null(flat_header)) {
     flat_factories <- c('huxtable', 'dataframe', 'typst')
     flat_formats <- c('markdown', 'word', 'powerpoint', 'typst')
-    if (settings_get("output_factory") %in% flat_factories ||
-        settings_get("output_format") %in% flat_formats) {
+    if (output_factory %in% flat_factories ||
+        output_format %in% flat_formats) {
         attr(tab, "header_bottom") <- colnames(tab)
 
       # datasummary_balance with dinm produces more cols than flat_header
@@ -65,7 +67,7 @@ factory <- function(tab,
   }
 
   # de-duplicate columns with whitespace
-  colnames(tab) <- pad(colnames(tab))
+  colnames(tab) <- pad(colnames(tab), output_format = output_format)
 
   # add_columns
   if (!is.null(add_columns)) {
@@ -124,7 +126,7 @@ factory <- function(tab,
   if (!is.null(add_rows)) {
 
     # data.frame includes metadata columns
-    if (settings_equal("output_format", "dataframe")) {
+    if (identical(output_format, "dataframe")) {
       # only for modelsummary, not for datasummary
 
       if (all(c("term", "statistic") %in% colnames(tab))) {
@@ -173,10 +175,10 @@ factory <- function(tab,
   align <- strsplit(align, "")[[1]]
 
   # dot align with unicode spaces (latex has its own mechanism)
-  if (!settings_equal("output_format", c("latex", "tinytable"))) {
+  if (!output_format %in% c("latex", "tinytable")) {
     align_d <- grep("d", align)
     for (i in align_d) {
-      tab[[i]] <- pad(tab[[i]], style = "character")
+      tab[[i]] <- pad(tab[[i]], style = "character", output_format = output_format)
     }
     align[align == "d"] <- "c"
   }
@@ -188,6 +190,8 @@ factory <- function(tab,
     notes = notes,
     title = title,
     escape = escape,
+    output_format = output_format,
+    output_file = output_file,
     ...)
 
 
