@@ -12,6 +12,8 @@ factory_gt <- function(tab,
                        notes = NULL,
                        title = NULL,
                        escape = TRUE,
+                       output_format = "gt",
+                       output_file = NULL,
                        ...) {
 
   insight::check_if_installed("gt", minimum_version = "0.5.0")
@@ -26,14 +28,14 @@ factory_gt <- function(tab,
   # create gt table object
   idx_col <- ncol(tab)
   colnames(tab)[is.na(colnames(tab))] <- ""
-  colnames(tab) <- pad(colnames(tab))
+  colnames(tab) <- pad(colnames(tab), output_format = output_format)
   out <- gt::gt(tab, caption = title)
 
   # theme
   theme_ms <- getOption("modelsummary_theme_gt",
                         default = theme_ms_gt)
   out <- theme_ms(out,
-                  output_format = settings_get("output_format"),
+                  output_format = output_format,
                   hrule = hrule,
                   hgroup = hgroup)
 
@@ -67,27 +69,27 @@ factory_gt <- function(tab,
   }
 
   # output
-  if (is.null(settings_get("output_file"))) {
+  if (is.null(output_file)) {
 
-    if (settings_equal("output_format", "html")) {
+    if (identical(output_format, "html")) {
       out <- gt::as_raw_html(out)
     }
 
-    if (settings_equal("output_format", "latex")) {
+    if (identical(output_format, "latex")) {
       out <- gt::as_latex(out)
     }
 
     if (!is.null(getOption("modelsummary_orgmode")) &&
-        settings_equal("output_format", c("html", "latex"))) {
-      out <- sprintf("#+BEGIN_EXPORT %s\n%s\n#+END_EXPORT", settings_get("output_format"), out)
+        output_format %in% c("html", "latex")) {
+      out <- sprintf("#+BEGIN_EXPORT %s\n%s\n#+END_EXPORT", output_format, out)
       return(out)
     }
 
-    if (settings_equal("output_format", c("default", "gt"))) {
+    if (output_format %in% c("default", "gt")) {
       return(out)
     }
 
   } else {
-    gt::gtsave(out, settings_get("output_file"))
+    gt::gtsave(out, output_file)
   }
 }
