@@ -8,6 +8,8 @@ factory_huxtable <- function(tab,
                              hrule = NULL,
                              notes = NULL,
                              title = NULL,
+                             output_format = "huxtable",
+                             output_file = NULL,
                              ...) {
 
 
@@ -41,19 +43,19 @@ factory_huxtable <- function(tab,
   out <- theme_ms(out, hrule = hrule)
 
   # output
-  output_file <- settings_get("output_file")
+  output_file <- output_file
   if (is.null(output_file)) {
     return(out)
   } else {
-    if (settings_equal("output_format", "word")) {
+    if (identical(output_format, "word")) {
       huxtable::quick_docx(out, file = output_file, open = FALSE)
-    } else if (settings_equal("output_format", "powerpoint")) {
+    } else if (identical(output_format, "powerpoint")) {
       huxtable::quick_pptx(out, file = output_file, open = FALSE)
-    } else if (settings_equal("output_format", "html")) {
+    } else if (identical(output_format, "html")) {
       huxtable::quick_html(out, file = output_file, open = FALSE)
-    } else if (settings_equal("output_format", "rtf")) {
+    } else if (identical(output_format, "rtf")) {
       huxtable::quick_rtf(out, file = output_file, open = FALSE)
-    } else if (settings_equal("output_format", "latex")) {
+    } else if (identical(output_format, "latex")) {
       huxtable::quick_latex(out, file = output_file, open = FALSE)
     }
   }
