@@ -11,16 +11,19 @@ factory_kableExtra <- function(tab,
                                notes = NULL,
                                title = NULL,
                                escape = TRUE,
+                               output_format = "kableExtra",
+                               output_file = NULL,
                                ...) {
 
   insight::check_if_installed("kableExtra")
 
-  output_format <- settings_get("output_format")
-
   span_list <- get_span_kableExtra(tab)
 
   # escape
   if (isTRUE(escape) && isTRUE(output_format %in% c("latex", "html", "typst"))) {
+    # escape ourselves rather than use the kableExtra escaping
+    escape <- FALSE
+
     tmp <- escape_everything(
       tab = tab,
       output_format = output_format,
@@ -35,9 +38,9 @@ factory_kableExtra <- function(tab,
 
   # new variable "kable_format" because "kableExtra" and "html" both produce
   # html, but we need to distinguish the two.
-  if (settings_equal("output_format", c("latex", "latex_tabular"))) {
+  if (output_format %in% c("latex", "latex_tabular")) {
     kable_format <- "latex"
-  } else if (settings_equal("output_format", "markdown")) {
+  } else if (identical(output_format, "markdown")) {
     kable_format <- "markdown"
   } else {
     kable_format <- "html"
@@ -57,22 +60,20 @@ factory_kableExtra <- function(tab,
     "caption"   = title,
     "format"    = kable_format,
     "booktabs"  = TRUE,
-    "escape" = FALSE, # never use kableExtra's default escape; inconsistent
+    "escape" = escape,
     "linesep"   = "",
     "row.names" = NULL
   )
 
-  ## siunitx in preamble
   extra_siunitx <- "
-  \\newcolumntype{d}{S[
-    input-open-uncertainty=,
-    input-close-uncertainty=,
-    parse-numbers = false,
-    table-align-text-pre=false,
-    table-align-text-post=false
-  ]}
+    \\newcolumntype{d}{S[
+      table-align-text-before=false,
+      table-align-text-after=false,
+      input-symbols={-,\\*+()}
+    ]}
   "
-  if (settings_equal("output_format", c("latex", "latex_tabular")) &&
+
+  if (output_format %in% c("latex", "latex_tabular") &&
       settings_equal("format_numeric_latex", "siunitx")) {
     invisible(knitr::knit_meta_add(list(
       rmarkdown::latex_dependency("booktabs"))))
@@ -84,7 +85,7 @@ factory_kableExtra <- function(tab,
   if (!is.null(align)) {
     for (i in seq_along(align)) {
       if (align[i] == "d") {
-        if (settings_equal("output_format", c("latex", "latex_tabular"))) {
+        if (output_format %in%  c("latex", "latex_tabular")) {
           ## protect strings from siunitx
           tab[[i]] <- ifelse(!grepl("[0-9]", tab[[i]]), sprintf("{%s}", tab[[i]]), tab[[i]]) 
         } else {
@@ -100,7 +101,7 @@ factory_kableExtra <- function(tab,
   }
 
   # Issue #669: <0.001 gets printed as a tag in HTML
-  if (settings_equal("output_format", c("kableExtra", "html"))) {
+  if (output_format %in% c("kableExtra", "html")) {
     for (i in seq_along(tab)) {
       idx <- grepl("<[^>]*$", tab[[i]]) | grepl("^[^<]*>", tab[[i]])
       # Brackets are not matching, perform substitution
@@ -111,7 +112,7 @@ factory_kableExtra <- function(tab,
 
   # kableExtra sometimes converts (1), (2) to list items, which breaks formatting
   # insert think white non-breaking space
-  if (settings_equal("output_format", c("html", "kableExtra"))) {
+  if (output_format %in% c("html", "kableExtra")) {
       regex <- paste0(paste(1:12, collapse = "|"), "|", paste(utils::as.roman(1:12), collapse = "|"))
       regex <- paste0("^\\(", regex, "\\)$")
       idx <- grepl(regex, colnames(tab))
@@ -133,7 +134,7 @@ factory_kableExtra <- function(tab,
 
   ## kableExtra::footnote bug when adding multiple notes with threeparttable in LaTeX
   ## combine notes
-  if (settings_equal("output_format", "latex") &&
+  if (identical(output_format, "latex") &&
       !is.null(notes) &&
       length(notes) > 1 &&
       "threeparttable" %in% names(arguments) &&
@@ -145,7 +146,7 @@ factory_kableExtra <- function(tab,
   if (!is.null(notes)) {
     ## kableExtra::footnote does not support markdown
     ## kableExtra::add_footnote does not support longtable
-    if (settings_equal("output_format", c("kableExtra", "html", "latex"))) {
+    if (output_format %in% c("kableExtra", "html", "latex")) {
       if (isTRUE(kable_format == "latex") && any(grepl(" < ", notes))) {
         notes <- gsub(" < ", " $<$ ", notes)
       }
@@ -154,11 +155,17 @@ factory_kableExtra <- function(tab,
       arguments[["general"]] <- notes
       arguments[["general_title"]] <- ""
       arguments[["kable_input"]] <- out
-      arguments[["escape"]] <- FALSE
+
+      # Issue #855: When output="kableExtra", we do not know the ultimate output format, 
+      # so we must rely on kableExtra's escaping for notes.
+      if (identical(output_format, "kableExtra")) {
+        arguments[["escape"]] <- escape
+      }
+
       if (isTRUE(any(nchar(arguments$general) > 0))) {
         out <- do.call(kableExtra::footnote, arguments)
       }
-    } else if (settings_equal("output_format", "markdown")) {
+    } else if (identical(output_format, "markdown")) {
       for (n in notes) {
         out <- kableExtra::add_footnote(out, label = n, notation = "none", escape = FALSE)
       }
@@ -170,34 +177,34 @@ factory_kableExtra <- function(tab,
                         default = theme_ms_kableExtra)
   out <- theme_ms(
     out,
-    output_format = settings_get("output_format"),
+    output_format = output_format,
     hrule = hrule,
     hgroup = hgroup,
     hindent = hindent,
     ...)
 
   # span: apply (not supported in markdown)
-  if (!is.null(span_list) && settings_equal("output_format", c("kableExtra", "latex", "html"))) {
+  if (!is.null(span_list) && output_format %in% c("kableExtra", "latex", "html")) {
     for (i in 1:length(span_list)) {
       sp <- span_list[[i]]
       names(span_list[[i]]) <- gsub("&nbsp;", " ", names(span_list[[i]]))
-      out <- kableExtra::add_header_above(out, span_list[[i]], escape = TRUE)
+      out <- kableExtra::add_header_above(out, span_list[[i]], escape = escape)
     }
   }
 
   # html & latex get a new class to use print.modelsummary_string
-  if (settings_equal("output_format", c("latex", "latex_tabular", "html"))) {
+  if (output_format %in% c("latex", "latex_tabular", "html")) {
     class(out) <- c("modelsummary_string", class(out))
   }
 
   # output
-  if (is.null(settings_get("output_file"))) {
+  if (is.null(output_file)) {
     return(out)
   } else {
-    if (settings_equal("output_format", "markdown")) {
-      writeLines(paste(out, collapse = "\n"), con = settings_get("output_file"))
+    if (identical(output_format, "markdown")) {
+      writeLines(paste(out, collapse = "\n"), con = output_file)
     } else {
-      kableExtra::save_kable(out, file = settings_get("output_file"))
+      kableExtra::save_kable(out, file = output_file)
     }
   }
 }
