@@ -24,7 +24,7 @@ make_stars <- function(pvalues, stars) {
   }
 
   # Remove this code because the new tinytable default uses a better set of options for siunitx by default, which handles *-+() gracefully
-  # if (settings_equal("output_format", "latex") && settings_equal("dcolumn_stars_mbox", TRUE)) {
+  # if (identical(output_format, "latex") && settings_equal("dcolumn_stars_mbox", TRUE)) {
   #   tmp <- sprintf(" \\mbox{%s}", tmp)
   # }
 
@@ -35,10 +35,14 @@ make_stars <- function(pvalues, stars) {
 #' Internal function to prepare stars footnote
 #'
 #' @noRd
-make_stars_note <- function(stars) {
+make_stars_note <- function(stars, output_format = NULL) {
   out <- clean_stars(stars)
   if (!is.null(out)) {
-    out <- paste0(names(out), ' p < ', out)
+    if (identical(output_format, "latex")) {
+      out <- paste0(names(out), ' p \\num{< ', out, "}")
+    } else {
+      out <- paste0(names(out), ' p < ', out)
+    }
     out <- paste0(out, collapse = ', ')
   }
   return(out)
